@@ -1,9 +1,9 @@
 # fields/unknown -- lintian check script (rewrite) -*- perl -*-
 #
-# Copyright (C) 2004 Marc Brockschmidt
+# Copyright © 2004 Marc Brockschmidt
 #
 # Parts of the code were taken from the old check script, which
-# was Copyright (C) 1998 Richard Braakman (also licensed under the
+# was Copyright © 1998 Richard Braakman (also licensed under the
 # GPL 2 or higher)
 #
 # This program is free software; you can redistribute it and/or modify
@@ -24,15 +24,17 @@
 
 package Lintian::fields::unknown;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
-use Moo;
-
 use Lintian::Data ();
 
-with('Lintian::Check');
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
 
 our $KNOWN_BINARY_FIELDS = Lintian::Data->new('fields/binary-fields');
 our $KNOWN_UDEB_FIELDS = Lintian::Data->new('fields/udeb-fields');
@@ -41,9 +43,9 @@ our $SOURCE_FIELDS      = Lintian::Data->new('common/source-fields');
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    for my $field (keys %{$info->field}) {
+    for my $field (keys %{$processable->field}) {
 
         $self->tag('unknown-field-in-dsc', $field)
           unless $SOURCE_FIELDS->known($field);
@@ -55,9 +57,9 @@ sub source {
 sub binary {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    for my $field (keys %{$info->field}) {
+    for my $field (keys %{$processable->field}) {
 
         $self->tag('unknown-field-in-control', $field)
           unless $KNOWN_BINARY_FIELDS->known($field);
@@ -69,9 +71,9 @@ sub binary {
 sub udeb {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    for my $field (keys %{$info->field}) {
+    for my $field (keys %{$processable->field}) {
 
         $self->tag('unknown-field-in-control', $field)
           unless $KNOWN_UDEB_FIELDS->known($field);
