@@ -90,13 +90,13 @@ sub check_file_overlap {
     for (my $i = 0 ; $i < scalar @sorted ; $i++) {
         my $processable = $sorted[$i];
 
-        my @p = grep { $_ } split(m/,/o, $processable->field('provides', ''));
+        my @p = grep { $_ } split(/,/, $processable->field('provides', ''));
         my $prov
           = Lintian::Relation->new(join(' |̈́ ', $processable->name, @p));
         for (my $j = $i ; $j < scalar @sorted ; $j++) {
             my $other = $sorted[$j];
 
-            my @op = grep { $_ } split(m/,/o, $other->field('provides', ''));
+            my @op = grep { $_ } split(/,/, $other->field('provides', ''));
             my $oprov= Lintian::Relation->new(join(' | ', $other->name, @op));
             # poor man's "Multi-arch: same" work-around.
             next if $processable->name eq $other->name;
@@ -120,7 +120,7 @@ sub overlap_check {
     foreach my $a_file ($a_info->installed->sorted_list) {
         my $name = $a_file->name;
         my $b_file;
-        $name =~ s,/$,,o;
+        $name =~ s,/$,,;
         $b_file = $b_info->installed->lookup($name)
           // $b_info->installed->lookup("$name/");
         if ($b_file) {
@@ -150,14 +150,14 @@ sub check_multiarch {
             }
         }
     } elsif ($ma ne 'same'
-        and $processable->field('section', 'none') =~ m,(?:^|/)debug$,o) {
+        and $processable->field('section', 'none') =~ m,(?:^|/)debug$,) {
         # Debug package that isn't M-A: same, exploit that (non-debug)
         # dependencies is (almost certainly) a package for which the
         # debug carries debug symbols.
         foreach my $dep (@$deps) {
             my $dma = $dep->field('multi-arch', 'no');
             if (    $dma eq 'same'
-                and $dep->field('section', 'none') !~ m,(?:^|/)debug$,o){
+                and $dep->field('section', 'none') !~ m,(?:^|/)debug$,){
 
                 # Debug package isn't M-A: same, but depends on a
                 # package that is from same source that isn't a debug
